#ifndef NEUTON_MODEL_MODEL_H
#define NEUTON_MODEL_MODEL_H

#ifdef __cplusplus
extern "C"
{
#endif

/* Model info */
#define NEUTON_MODEL_HEADER_VERSION 3
#define NEUTON_MODEL_QLEVEL 8
#define NEUTON_MODEL_FLOAT_SUPPORT 0
#define NEUTON_MODEL_TASK_TYPE 0  // multiclass classification
#define NEUTON_MODEL_NEURONS_COUNT 259
#define NEUTON_MODEL_WEIGHTS_COUNT 1881
#define NEUTON_MODEL_INPUTS_COUNT 784
#define NEUTON_MODEL_INPUT_LIMITS_COUNT 784
#define NEUTON_MODEL_OUTPUTS_COUNT 10
#define NEUTON_MODEL_LOG_SCALE_OUTPUTS 0
#define NEUTON_MODEL_HAS_CLASSES_RATIO 0
#define NEUTON_MODEL_HAS_NEGPOS_RATIO 0

/* Preprocessing */
#define NEUTON_PREPROCESSING_ENABLED 0
#define NEUTON_DROP_ORIGINAL_FEATURES 0
#define NEUTON_BITMASK_ENABLED 1
#define NEUTON_MODEL_SA_PRECISION 24

/* Types */
typedef float input_t;
typedef float extracted_feature_t;
typedef uint8_t coeff_t;
typedef int8_t weight_t;
typedef int32_t acc_signed_t;
typedef uint32_t acc_unsigned_t;
typedef uint16_t sources_size_t;
typedef uint16_t weights_size_t;
typedef uint16_t neurons_size_t;

/* Limits */
static const input_t modelInputMin[] = {
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
static const input_t modelInputMax[] = {
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0,
	0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0 };

static const uint8_t modelUsedInputsMask[] = {
	0x00, 0x00, 0x00, 0x00, 0x70, 0xe9, 0x00, 0xe0, 0xb8, 0xbb, 0x00, 0xda,
	0x7f, 0x37, 0xb0, 0xff, 0x7e, 0x81, 0xfe, 0xff, 0x3b, 0x80, 0xef, 0xbf,
	0x8a, 0xe7, 0xff, 0x5b, 0x3e, 0xf7, 0xff, 0x63, 0x79, 0xff, 0x3f, 0x76,
	0xff, 0xbf, 0xd5, 0xff, 0xff, 0x3f, 0xba, 0xfd, 0xef, 0x08, 0xfc, 0xff,
	0x4e, 0xe4, 0xff, 0x7f, 0x45, 0xfd, 0xff, 0x13, 0xe4, 0xff, 0x7f, 0x07,
	0xfa, 0xdf, 0x74, 0x58, 0xff, 0x2f, 0x05, 0xdf, 0xde, 0x3d, 0xc8, 0x9f,
	0x9b, 0x27, 0xbc, 0x7f, 0x49, 0xb4, 0x7e, 0xf5, 0x03, 0x73, 0x73, 0x50,
	0x90, 0x7e, 0x71, 0x41, 0xfe, 0xff, 0x1f, 0xe0, 0xd3, 0x7f, 0x00, 0xa2,
	0x34, 0x02 };

/* Structure */
static const weight_t modelWeights[] = {
	106, 102, -112, 84, 85, 124, -93, 7, 100, 96, -111, 109, 86, 32, 37, 80,
	-35, -23, -26, 71, 14, -84, 78, -94, 94, -127, 90, 124, 126, 98, -77, -91,
	63, 78, 17, -45, -73, 46, -9, 2, 124, 69, -68, 103, 70, 69, 2, -84, 118,
	-55, 56, 71, 85, 72, -26, -29, -33, -35, 14, 95, 119, -122, 125, -116,
	117, 121, -113, -98, 82, -98, -87, 4, 124, -33, -57, -28, 102, 9, 83, 124,
	-96, 98, 124, -8, 39, -36, -48, -49, -39, 124, -9, -14, 120, 81, -66, 88,
	85, 85, -5, 95, -98, -128, -128, -4, 103, -95, -90, 76, -6, 102, 93, 124,
	0, -94, -128, -21, -128, -11, 109, 109, 115, -6, -101, 120, 124, -47, -18,
	6, -41, -33, 103, 85, 91, -60, 21, -121, 49, -92, -50, -94, 7, 39, -127,
	-72, 101, -25, 10, 120, -73, -73, -81, -128, 45, 11, 97, -46, -15, -14,
	-99, -2, 20, 29, 86, -128, -108, 29, 43, 124, 77, 67, -104, -39, 126, 34,
	-128, 99, -86, -122, -50, 95, 124, 124, 67, -71, 109, -68, -26, 116, 2,
	-38, 53, -89, 15, 75, -118, -128, -21, -128, -128, -128, -128, -128, -2,
	27, -115, 80, -28, -86, 1, 125, 77, 124, 37, -15, -105, 12, -50, -55, 63,
	124, -72, -128, -128, 0, -63, -128, 0, -71, -42, -128, 50, 114, -123, -85,
	-6, 34, -23, 125, 4, 5, 36, 44, -61, -5, 114, -5, -60, 75, -126, 114, 123,
	-128, -71, -40, -63, -113, 125, 125, 125, -32, 29, -107, 112, -38, -86,
	-47, -126, -128, -43, 61, -65, -128, -128, 61, -2, -32, -128, -83, -11,
	109, -3, -2, 61, 124, -128, 124, -2, 30, 60, -32, -124, -106, 11, 37, 5,
	-128, 36, -128, -83, 109, -80, 125, -56, 28, -66, -65, -128, -2, -128,
	-128, -2, -28, -9, -128, -99, 61, 29, -10, -104, 110, 19, -46, 10, -85,
	120, 114, -24, -82, 115, -115, -126, -128, -50, 68, 124, -39, -27, -5,
	-114, -85, -48, -62, -114, 3, 39, 3, 46, 118, 123, -26, -18, -45, -7, 0,
	40, 73, 42, 40, -128, 125, 113, 35, -87, 100, -4, -128, 90, -8, -128, -126,
	-30, -7, -111, 30, 94, -39, -110, 53, -128, -3, -79, -128, -128, -68, -114,
	6, -14, -44, -127, 111, 114, -107, 9, 119, 121, -45, -31, 54, -69, -16,
	-64, 113, -116, -40, -88, -4, -128, 30, -128, -128, -128, -3, 78, -116,
	-88, -128, 17, -98, -53, -128, -53, -128, -35, -70, 37, -128, -128, -58,
	36, 0, -128, 58, 123, 124, -80, 21, -125, -11, 105, 85, -128, -68, -41,
	-115, -127, -38, -37, -128, -62, 87, -106, 118, -74, 88, -7, 23, -125,
	-127, -52, -128, 50, -30, -128, 7, -98, -128, -3, -128, 29, -35, -25, 55,
	120, 57, 53, 15, -128, -27, -5, -124, -8, 38, 44, -63, -128, -28, -113,
	-128, 0, -128, -55, 124, 60, -128, 61, -128, 124, -128, -65, -94, 15, -71,
	40, -126, 105, -58, -46, -128, -99, 94, 76, -101, -119, 50, 89, -3, -14,
	125, 5, -48, 41, -29, 42, 124, 66, 0, -127, -128, 15, -128, -39, -10, 25,
	-74, -89, 76, -128, 77, -78, -61, 121, 32, -93, 0, -100, -128, 66, -11,
	59, 41, -120, -95, 101, 125, 109, 5, -4, -128, -21, -5, -128, -128, -128,
	0, -32, -7, 108, -128, -106, -128, -4, -2, 102, 125, -20, -24, -128, -44,
	-100, -126, -64, -128, -96, -20, 81, 19, -128, -65, -128, 124, -2, -2,
	18, -128, -7, -128, 37, -15, 109, -32, -47, -128, 38, -3, -82, -128, -128,
	-128, -58, -128, 44, -41, -8, 94, -47, -22, 16, -66, -128, -128, 30, -128,
	-36, 18, -8, 0, 124, -36, 45, -128, 13, -66, 21, 125, -104, -80, -74, 59,
	-58, -47, -126, -122, -128, -128, 50, -83, 98, 26, 113, 104, -118, 0, 82,
	-102, 85, -128, 33, -128, 15, -28, -128, 107, -50, -14, -15, -128, -2,
	-128, -128, -128, -2, 124, 124, -128, -128, -2, -128, 81, 55, -62, 15,
	114, -82, -46, -81, 67, -128, 82, -79, -56, 33, 68, -128, 104, -128, 124,
	82, 33, -106, 123, -42, -35, -128, 75, -13, -34, -50, -15, -34, 23, -3,
	-128, 54, 47, -30, -82, -69, 121, 95, 109, 124, -30, -97, 61, 56, -128,
	125, -21, -48, 122, -120, 109, -95, -125, 110, 78, -76, -118, -1, 83, -43,
	113, -2, -21, 2, 19, -31, -39, -122, -125, 72, 48, -4, 16, 123, -71, -65,
	63, -124, -62, -1, 124, 64, 34, 32, -61, 98, 0, -128, -128, 2, -97, 61,
	61, 124, -65, 61, -65, -27, 93, -35, 66, 118, -110, -95, 79, 37, -118,
	101, 26, -107, -39, 104, -2, 11, -5, -127, -96, -128, 52, 96, -63, -105,
	67, -85, 124, -120, 125, 65, -40, -128, 65, -101, 51, -30, 15, -79, -35,
	-118, 124, 123, -128, -128, -2, -128, -2, -2, 121, -97, -109, -25, 124,
	-2, -128, -128, -55, -55, -128, -55, 13, -128, -128, 61, -128, -128, -121,
	-32, -83, 17, 5, -113, -128, 106, -128, -15, 89, 0, -62, 55, 34, -125,
	-123, 31, -128, -128, 25, -11, -100, -128, -72, -128, -42, 52, 59, 117,
	-32, -128, -128, -119, 102, -35, -128, -128, -38, 86, 33, -81, 118, -128,
	-50, 105, -34, 126, -13, 6, 5, -128, -11, -128, -119, 30, -69, 4, 62, 85,
	-114, 54, 118, -69, -125, 80, 123, 124, -43, -75, 103, -128, -53, -72,
	-128, -128, -13, -65, 124, -128, -128, -128, -2, -25, -59, -23, -128, 57,
	87, -35, -68, 124, 48, 3, -47, -2, 5, 61, -32, -83, -32, 125, -3, -65,
	-65, -128, 124, -128, -65, -104, 73, -103, -50, 124, 7, -128, 51, 74, 42,
	73, -120, -68, -49, 5, 123, -128, -83, -128, 0, -2, -128, -128, -128, -2,
	-65, -128, 124, -2, 124, -128, 0, -54, 117, -128, 53, -36, 125, 0, -59,
	119, 50, 61, -128, -128, 89, -4, -128, -40, 81, 97, -24, 125, -115, -103,
	-4, -128, 74, 36, 106, 124, -45, -109, -38, -128, 100, -128, -20, -128,
	93, -128, -128, 40, -35, -106, 57, 5, 109, 78, -25, -100, 97, 61, 62, -44,
	-128, 4, -128, 70, 2, -128, -47, -17, -124, 6, 0, 86, -128, 99, -101, -64,
	50, 58, 63, -58, 58, 61, -54, 124, -111, 46, -66, -52, 58, -27, 24, 50,
	115, -75, -95, -128, 49, -87, 41, -62, -118, -128, -80, 79, -30, -64, 32,
	61, 16, 7, -112, 36, 32, -72, -31, 123, -24, 65, -6, -128, 102, -60, -25,
	112, 14, -2, 124, 124, 61, -65, -65, -85, -128, 41, -17, 41, -128, 2, 100,
	65, -40, -116, -21, -15, -46, -128, -44, 35, 1, -128, 60, 50, -128, -128,
	-26, -128, 0, 5, -65, -128, -65, -128, -128, -2, 0, -128, -128, -67, 49,
	-83, -9, -118, -128, 16, 11, 73, -23, -82, 63, 46, 49, 110, 2, -115, 124,
	-128, 109, -128, -120, -96, 96, -17, -112, -84, 0, -23, -121, -128, -123,
	-125, 76, 0, 29, -128, -65, 124, -128, -128, -2, -119, 17, -79, 54, 123,
	-72, -128, 121, -43, 121, 65, -116, 120, -128, 108, -128, 0, -76, -5, -128,
	-128, 26, -128, -128, -47, 59, -41, -13, -82, 124, 1, 124, -65, 61, -2,
	-65, -65, -128, 124, -128, -2, 61, -128, -45, -38, -22, -23, -51, -128,
	-37, -23, -17, -47, -32, 43, 69, -59, -97, -95, 42, -79, 23, -43, -81,
	-34, -13, -128, -13, -66, -18, 51, 35, -56, 125, -90, 45, -108, -113, 91,
	121, 117, 24, 10, -44, 26, 17, 81, -21, 77, 72, -83, -14, -28, -72, 13,
	93, 96, -128, 104, 39, 70, -124, -128, -47, -115, 0, 12, 19, -95, -128,
	53, -22, -100, -128, -66, 35, 91, -75, 114, 97, -33, -104, -128, -1, -128,
	26, -128, -128, -22, -128, -26, -2, -44, -128, -128, -3, -128, -128, -2,
	37, -111, -128, -105, 13, -73, -66, -126, 83, 3, 93, -128, -111, 94, 124,
	-82, 111, 13, -25, -34, -64, -10, -66, 124, 93, 70, 88, 98, -127, -65,
	-106, 22, -36, 104, -5, 43, 76, -88, 50, 30, -89, -68, 45, -55, 29, -128,
	-70, 107, -51, 113, -29, -29, 73, 0, -128, -36, 23, 37, -15, -4, 125, 126,
	23, 115, 7, 97, -70, -128, 53, 67, 19, -59, 47, -8, -65, -128, -128, 61,
	-128, -65, -96, -128, 62, -128, -125, 10, -23, 33, -128, -128, -128, -128,
	0, -122, 27, -50, -8, 86, -63, -13, -92, 38, -76, 122, -108, 20, -57, -37,
	-2, -21, 73, 124, 124, -35, -128, -50, -67, -70, -79, -128, 26, -128, 107,
	122, 75, -27, -70, -23, -3, -8, -16, -111, 9, 122, -41, -6, 125, 125, -83,
	-128, -50, -3, -122, -98, 98, -29, -68, -46, 10, -50, 74, -116, -128, 49,
	59, -2, -2, -128, -65, 61, -2, 101, 10, -32, 110, -10, -128, -20, -117,
	-128, -102, 96, -128, -98, 4, -100, 38, -100, -9, -128, 0, -1, -81, 49,
	-12, 124, -53, -65, -62, -50, -50, 57, 114, -73, -128, -51, 9, -128, -128,
	-9, -119, -89, -95, 73, -95, 125, -128, -128, -128, -128, 1, -3, 2, -82,
	105, -128, -128, 104, -108, -60, -118, -98, -128, -111, 104, -21, 125,
	83, -76, 46, -23, -52, -95, 19, -37, 18, 61, 11, -59, -39, 82, 37, -128,
	-70, -128, 54, -80, -120, -48, -57, 96, 30, 35, -128, 61, -79, 0, 4, 110,
	-97, -38, -26, 82, -9, 1, 118, 24, 48, 120, 47, -82, -40, 113, 124, -128,
	-15, -43, -50, 64, 93, -128, -128, -93, -34, -119, -4, -128, -128, -5,
	0, 122, -11, 13, -15, 47, 58, -100, -67, 62, 58, 21, -21, 39, 64, -128,
	42, -111, 84, 64, -124, -110, -127, 46, -24, 57, -128, 122, 52, -73, -41,
	54, -80, -25, 51, -97, 84, -68, -64, 87, -128, -128, 10, -112, -42, -1,
	114, -113, -116, -39, 0, -84, -128, -46, -34, 33, -21, 60, -122, 77, 34,
	15, -63, 42, 43, -128, -128, 37, -105, -128, -128, -65, -128, 61, -128,
	-128, -2, -47, -57, -35, -38, -14, -58, -110, -58, 14, -29, -29, -78, 121,
	-51, 21, 124, -26, 72, 124, -25, 116, -43, -15, -22, -121, 39, -18, 29,
	-116, 45, 36, 36, -124, -128, 3, 94, 116, -96, -100, 103, 93, 64, 43, 95,
	53, -75, 60, -128, 41, 108, -56, 106, -128, 77, -81, -90, 68, -120, 69,
	33, -128, 125, 40, -40, -106, 99, -128, -114, 124, -61, 8, -60, -128, -128,
	-128, -128, 1, -28, -128, -1, -128, -128, -4, 89, 39, -128, 42, -128, -128,
	-114, -128, -128, -128, -128, 68, 19, -82, -80, -128, -102, 82, -65, -56,
	-128, -75, -72, 54, 61, 61, 124, 61, 124, -128, 55, -128, -37, -128, -35,
	14, -57, -59, 69, 70, -27, -74, 57, -41, -26, -68, -64, -128, -51, 23,
	30, -39, 67, -51, 28, -29, -128, 35, -14, 23, -28, -81, 39, 33, -21, 34,
	-17, -69, 38, -39, -50, -128, -31, 45, -42, -57, 22, -82, -37, 31, -62,
	-73, -24, -19, 114, -128, 78, -54, 22, -73, 38, 17, 65, 50, -57, -68, 78,
	-124, -41, 39, -88, 93, 63, 87, 15 };

static const sources_size_t modelLinks[] = {
	146, 351, 359, 408, 434, 462, 568, 784, 177, 290, 378, 411, 465, 784, 319,
	344, 554, 567, 608, 685, 784, 177, 370, 377, 489, 563, 784, 62, 127, 211,
	409, 429, 597, 784, 3, 219, 277, 327, 346, 355, 358, 242, 542, 652, 656,
	661, 784, 6, 156, 266, 403, 405, 539, 784, 376, 433, 487, 656, 744, 784,
	156, 211, 227, 317, 570, 784, 220, 289, 324, 486, 518, 784, 73, 370, 429,
	431, 716, 784, 236, 247, 322, 355, 510, 784, 153, 314, 347, 349, 372, 501,
	784, 4, 67, 96, 464, 736, 740, 744, 784, 160, 267, 269, 272, 328, 656,
	784, 2, 13, 99, 277, 686, 692, 784, 2, 193, 458, 579, 661, 706, 710, 714,
	784, 12, 71, 143, 233, 236, 784, 7, 9, 163, 249, 444, 458, 784, 4, 400,
	596, 636, 661, 784, 205, 316, 319, 469, 485, 784, 108, 327, 354, 380, 746,
	784, 0, 7, 22, 466, 551, 784, 1, 377, 492, 649, 748, 784, 0, 22, 131, 148,
	248, 784, 3, 120, 233, 387, 681, 784, 5, 268, 584, 668, 742, 784, 8, 89,
	208, 329, 604, 784, 5, 22, 156, 185, 275, 383, 498, 784, 21, 91, 181, 237,
	292, 784, 268, 330, 528, 630, 632, 784, 13, 71, 98, 126, 290, 397, 657,
	784, 3, 123, 146, 206, 333, 528, 784, 8, 134, 281, 318, 343, 515, 784,
	133, 406, 407, 463, 522, 784, 30, 295, 409, 500, 594, 784, 547, 570, 577,
	606, 686, 784, 32, 254, 321, 347, 517, 784, 5, 62, 226, 507, 515, 784,
	26, 153, 211, 237, 568, 594, 748, 784, 109, 324, 355, 385, 641, 784, 457,
	514, 516, 557, 737, 784, 19, 398, 414, 657, 743, 784, 347, 353, 489, 552,
	627, 784, 205, 434, 542, 545, 653, 784, 108, 132, 225, 463, 601, 784, 22,
	201, 261, 296, 545, 784, 183, 329, 566, 569, 679, 712, 784, 43, 274, 322,
	494, 657, 784, 79, 100, 232, 243, 282, 784, 10, 248, 370, 537, 584, 603,
	628, 784, 98, 184, 202, 212, 295, 296, 426, 784, 21, 52, 133, 241, 288,
	784, 0, 1, 2, 3, 229, 256, 784, 27, 68, 236, 319, 649, 784, 10, 96, 191,
	260, 318, 323, 784, 3, 151, 239, 372, 403, 784, 127, 246, 347, 349, 372,
	551, 637, 656, 784, 0, 1, 164, 518, 523, 784, 75, 94, 374, 426, 568, 693,
	784, 455, 500, 548, 597, 656, 784, 55, 129, 337, 371, 411, 784, 158, 267,
	326, 337, 608, 784, 35, 60, 441, 481, 629, 656, 784, 8, 399, 400, 720,
	742, 748, 784, 222, 256, 464, 490, 694, 784, 62, 353, 379, 486, 551, 784,
	11, 201, 292, 346, 657, 719, 784, 60, 182, 259, 348, 555, 784, 60, 349,
	373, 399, 584, 773, 784, 22, 176, 208, 339, 378, 784, 4, 29, 45, 100, 200,
	219, 557, 770, 784, 4, 29, 59, 185, 188, 241, 784, 3, 15, 306, 430, 491,
	507, 784, 12, 406, 409, 556, 638, 784, 12, 37, 265, 321, 487, 652, 784,
	265, 318, 411, 521, 712, 784, 0, 24, 29, 508, 517, 585, 784, 1, 106, 298,
	333, 640, 735, 784, 60, 153, 205, 208, 515, 648, 784, 12, 444, 461, 543,
	684, 784, 41, 44, 510, 516, 577, 784, 24, 266, 459, 468, 618, 784, 5, 418,
	501, 668, 714, 784, 12, 43, 187, 262, 359, 517, 784, 18, 21, 164, 228,
	426, 487, 491, 784, 12, 22, 435, 437, 483, 486, 784, 6, 18, 428, 458, 489,
	539, 784, 21, 436, 548, 583, 742, 784, 16, 42, 163, 399, 472, 784, 69,
	89, 268, 348, 719, 784, 79, 351, 409, 413, 540, 770, 784, 5, 117, 176,
	233, 313, 594, 784, 34, 78, 290, 491, 515, 713, 784, 26, 41, 129, 189,
	303, 313, 784, 65, 226, 323, 405, 611, 784, 3, 210, 378, 407, 521, 722,
	784, 3, 43, 116, 145, 310, 372, 784, 42, 47, 129, 269, 378, 784, 242, 243,
	357, 416, 426, 696, 784, 35, 340, 428, 481, 494, 784, 100, 187, 271, 460,
	488, 784, 72, 188, 239, 464, 737, 784, 17, 186, 267, 551, 566, 784, 1,
	156, 525, 595, 661, 784, 81, 272, 538, 575, 681, 784, 57, 208, 211, 494,
	545, 629, 683, 784, 19, 273, 490, 502, 600, 784, 7, 9, 99, 108, 241, 724,
	784, 6, 53, 136, 245, 282, 784, 19, 76, 519, 630, 640, 784, 29, 227, 403,
	487, 488, 623, 784, 37, 285, 353, 537, 538, 784, 209, 301, 405, 454, 568,
	784, 145, 220, 314, 323, 465, 784, 4, 69, 71, 239, 611, 712, 784, 80, 297,
	320, 502, 530, 784, 23, 214, 253, 297, 585, 784, 35, 214, 266, 470, 640,
	784, 1, 153, 200, 236, 737, 784, 22, 113, 79, 292, 721, 784, 101, 205,
	242, 244, 373, 424, 784, 102, 241, 315, 410, 747, 784, 119, 210, 268, 294,
	685, 784, 0, 1, 2, 3, 124, 784, 125, 183, 375, 459, 625, 784, 88, 90, 454,
	513, 716, 784, 152, 236, 292, 402, 440, 576, 784, 94, 177, 377, 474, 522,
	784, 0, 1, 2, 3, 62, 128, 310, 330, 784, 331, 377, 436, 495, 580, 784,
	60, 284, 355, 626, 640, 784, 8, 42, 430, 517, 605, 784, 165, 214, 296,
	299, 512, 784, 107, 215, 239, 242, 460, 709, 784, 7, 11, 26, 303, 765,
	784, 0, 1, 2, 3, 269, 460, 597, 784, 0, 1, 2, 4, 580, 784, 19, 27, 159,
	572, 684, 707, 708, 784, 6, 61, 328, 410, 599, 602, 777, 784, 0, 306, 460,
	464, 585, 784, 236, 321, 379, 387, 546, 556, 784, 3, 76, 105, 175, 483,
	688, 784, 50, 80, 106, 240, 735, 784, 1, 374, 444, 662, 710, 784, 139,
	495, 520, 602, 720, 784, 45, 125, 212, 358, 670, 784, 33, 155, 375, 390,
	770, 784, 20, 79, 295, 350, 404, 428, 784, 8, 98, 195, 614, 711, 716, 784,
	0, 126, 142, 253, 406, 745, 784, 4, 30, 49, 38, 101, 507, 705, 784, 92,
	114, 72, 270, 353, 639, 784, 2, 124, 130, 341, 352, 676, 707, 784, 64,
	108, 217, 416, 605, 784, 101, 115, 102, 576, 661, 784, 1, 42, 106, 112,
	248, 784, 5, 76, 102, 75, 332, 363, 784, 106, 69, 104, 295, 601, 784, 11,
	40, 96, 129, 412, 473, 784, 2, 13, 51, 56, 59, 90, 138, 139, 140, 141,
	142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156,
	157, 158, 159, 160, 784, 0, 1, 2, 3, 185, 784, 16, 60, 111, 113, 127, 242,
	722, 784, 69, 422, 572, 599, 639, 784, 72, 75, 219, 406, 457, 784, 41,
	77, 337, 550, 621, 761, 784, 147, 299, 357, 387, 429, 630, 784, 9, 45,
	248, 457, 734, 784, 68, 156, 237, 291, 660, 750, 784, 86, 130, 166, 150,
	232, 234, 784, 134, 154, 161, 216, 576, 784, 3, 253, 494, 569, 767, 784,
	7, 56, 142, 199, 306, 784, 109, 169, 160, 330, 348, 784, 97, 201, 450,
	484, 515, 670, 784, 66, 189, 216, 296, 461, 722, 784, 121, 95, 536, 589,
	600, 784, 132, 176, 456, 660, 723, 784, 12, 179, 205, 222, 266, 784, 90,
	63, 304, 308, 312, 430, 784, 70, 40, 269, 292, 323, 784, 32, 100, 130,
	290, 341, 784, 145, 298, 301, 398, 634, 784, 147, 298, 394, 401, 454, 784,
	6, 16, 57, 106, 127, 162, 164, 165, 166, 167, 168, 169, 170, 171, 172,
	173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 784, 0, 1,
	2, 3, 410, 784, 5, 30, 121, 131, 772, 784, 7, 17, 54, 58, 125, 126, 130,
	187, 784, 42, 43, 241, 576, 627, 784, 94, 161, 260, 348, 402, 784, 8, 143,
	271, 311, 485, 543, 784, 0, 1, 2, 3, 183, 784, 42, 90, 130, 213, 694, 749,
	784, 86, 191, 63, 295, 404, 694, 784, 49, 100, 149, 182, 239, 373, 418,
	784, 210, 297, 381, 437, 601, 784, 16, 81, 167, 267, 594, 784, 0, 99, 276,
	378, 403, 469, 784, 0, 1, 2, 3, 17, 93, 110, 71, 784, 5, 100, 112, 100,
	240, 784, 9, 95, 185, 268, 291, 325, 784, 171, 293, 402, 406, 596, 784,
	39, 129, 133, 177, 379, 743, 784, 101, 265, 300, 399, 682, 784, 17, 90,
	179, 386, 463, 707, 784, 78, 150, 104, 439, 462, 467, 784, 184, 414, 459,
	518, 722, 784, 163, 46, 459, 521, 603, 784, 82, 125, 132, 142, 542, 654,
	784, 0, 1, 4, 5, 489, 784, 0, 1, 2, 3, 215, 406, 784, 0, 1, 2, 3, 382,
	719, 742, 784, 0, 11, 163, 199, 200, 210, 211, 212, 784, 102, 118, 124,
	354, 465, 784, 0, 1, 2, 3, 127, 227, 784, 99, 160, 208, 265, 627, 784,
	2, 85, 122, 267, 632, 660, 784, 4, 184, 402, 406, 513, 784, 275, 327, 405,
	412, 427, 784, 15, 60, 134, 274, 373, 784, 90, 137, 195, 269, 293, 347,
	536, 784, 3, 34, 164, 125, 220, 715, 784, 9, 17, 487, 606, 718, 784, 55,
	163, 300, 376, 455, 784, 163, 203, 126, 337, 620, 784, 1, 2, 3, 4, 320,
	784, 86, 171, 267, 424, 466, 784, 4, 12, 216, 178, 520, 652, 784, 14, 52,
	188, 213, 237, 304, 784, 85, 179, 264, 594, 626, 784, 60, 207, 321, 414,
	735, 784, 1, 12, 128, 137, 186, 192, 201, 202, 203, 204, 205, 206, 207,
	208, 209, 227, 228, 231, 784, 126, 92, 158, 271, 491, 770, 784, 7, 52,
	150, 202, 109, 748, 784, 60, 93, 191, 276, 379, 784, 22, 96, 142, 586,
	702, 784, 123, 142, 121, 264, 317, 516, 784, 15, 172, 214, 238, 332, 567,
	784, 3, 10, 24, 26, 27, 33, 34, 63, 74, 75, 76, 77, 78, 79, 80, 81, 82,
	83, 84, 85, 197, 198, 214, 215, 217, 219, 235, 236, 237, 238, 784, 13,
	30, 36, 157, 243, 784, 64, 205, 350, 411, 438, 784, 22, 126, 187, 347,
	373, 627, 134, 166, 134, 350, 543, 784, 6, 116, 37, 286, 432, 784, 88,
	234, 207, 317, 343, 439, 521, 784, 9, 19, 22, 25, 28, 32, 36, 53, 64, 65,
	66, 67, 68, 69, 70, 71, 72, 73, 129, 193, 194, 216, 223, 224, 226, 240,
	241, 242, 243, 244, 245, 784, 0, 1, 2, 3, 354, 784, 5, 15, 29, 86, 87,
	88, 89, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105,
	131, 134, 135, 136, 220, 229, 230, 234, 247, 784, 21, 60, 149, 291, 350,
	427, 784, 3, 127, 151, 407, 733, 784, 2, 163, 186, 189, 720, 784, 9, 61,
	79, 212, 233, 784, 8, 210, 154, 343, 348, 784, 181, 210, 293, 453, 571,
	784, 92, 106, 47, 492, 717, 784, 20, 96, 402, 408, 515, 784, 4, 14, 30,
	52, 55, 60, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118,
	119, 120, 121, 122, 123, 124, 189, 233, 251, 252, 253, 254, 255, 256, 784,
	8, 18, 20, 21, 23, 31, 35, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47,
	48, 49, 50, 61, 62, 132, 133, 190, 191, 195, 196, 218, 221, 222, 225, 249,
	250, 784 };

static const weights_size_t modelIntLinksBoundaries[] = {
	0, 8, 14, 21, 27, 35, 41, 48, 54, 60, 66, 72, 78, 84, 92, 99, 108, 114,
	123, 130, 136, 141, 147, 156, 160, 167, 172, 178, 184, 191, 198, 203, 210,
	218, 225, 231, 238, 243, 250, 256, 262, 269, 275, 282, 287, 293, 299, 306,
	311, 319, 324, 331, 338, 348, 356, 360, 366, 373, 378, 389, 393, 400, 407,
	412, 420, 426, 432, 438, 445, 452, 458, 465, 473, 482, 488, 494, 501, 506,
	515, 520, 527, 534, 541, 546, 552, 559, 566, 574, 581, 587, 594, 599, 605,
	612, 620, 627, 633, 639, 646, 654, 658, 666, 672, 677, 684, 690, 696, 702,
	710, 718, 724, 729, 735, 742, 747, 753, 761, 767, 773, 779, 785, 792, 797,
	804, 809, 819, 822, 829, 833, 840, 852, 855, 862, 869, 873, 880, 889, 896,
	904, 908, 916, 923, 928, 936, 945, 949, 955, 960, 967, 974, 981, 989, 996,
	1003, 1010, 1018, 1024, 1032, 1037, 1042, 1049, 1083, 1088, 1095, 1098,
	1106, 1111, 1118, 1126, 1130, 1140, 1145, 1151, 1159, 1164, 1168, 1176,
	1183, 1190, 1195, 1201, 1208, 1215, 1220, 1225, 1258, 1263, 1267, 1279,
	1282, 1287, 1293, 1303, 1307, 1314, 1323, 1327, 1336, 1341, 1353, 1358,
	1363, 1369, 1378, 1382, 1390, 1396, 1402, 1408, 1417, 1424, 1430, 1437,
	1449, 1453, 1461, 1463, 1471, 1478, 1482, 1491, 1497, 1505, 1511, 1517,
	1523, 1531, 1535, 1542, 1548, 1555, 1560, 1583, 1585, 1595, 1601, 1607,
	1612, 1619, 1654, 1657, 1662, 1669, 1675, 1681, 1687, 1724, 1729, 1762,
	1765, 1772, 1777, 1783, 1790, 1794, 1802, 1808, 1844, 1880 };
static const weights_size_t modelExtLinksBoundaries[] = {
	8, 14, 21, 27, 34, 41, 47, 54, 60, 66, 72, 78, 84, 91, 99, 106, 113, 122,
	128, 135, 141, 147, 153, 159, 165, 171, 177, 183, 189, 197, 203, 209, 217,
	224, 231, 237, 243, 249, 255, 261, 269, 275, 281, 287, 293, 299, 305, 311,
	318, 324, 330, 338, 346, 352, 359, 365, 372, 378, 387, 393, 400, 406, 412,
	418, 425, 432, 438, 444, 451, 457, 464, 470, 479, 486, 493, 499, 506, 512,
	519, 526, 533, 539, 545, 551, 557, 564, 572, 579, 586, 592, 598, 604, 611,
	618, 625, 632, 638, 645, 652, 658, 665, 671, 677, 683, 689, 695, 701, 709,
	715, 722, 728, 734, 741, 747, 753, 759, 766, 772, 778, 784, 790, 796, 803,
	809, 815, 821, 827, 833, 840, 846, 855, 861, 867, 873, 879, 886, 892, 900,
	906, 914, 922, 928, 935, 942, 948, 954, 960, 966, 972, 979, 986, 993, 1001,
	1008, 1016, 1022, 1028, 1034, 1041, 1047, 1054, 1084, 1090, 1098, 1104,
	1110, 1117, 1124, 1130, 1137, 1144, 1150, 1156, 1162, 1168, 1175, 1182,
	1188, 1194, 1200, 1207, 1213, 1219, 1225, 1231, 1259, 1265, 1271, 1280,
	1286, 1292, 1299, 1305, 1312, 1319, 1327, 1333, 1339, 1346, 1355, 1361,
	1368, 1374, 1381, 1387, 1394, 1401, 1407, 1413, 1420, 1426, 1433, 1441,
	1450, 1456, 1463, 1469, 1476, 1482, 1488, 1494, 1502, 1509, 1515, 1521,
	1527, 1533, 1539, 1546, 1553, 1559, 1565, 1584, 1591, 1598, 1604, 1610,
	1617, 1624, 1655, 1661, 1667, 1673, 1679, 1685, 1693, 1725, 1731, 1763,
	1770, 1776, 1782, 1788, 1794, 1800, 1806, 1812, 1845, 1881 };

static const coeff_t modelFuncCoeffs[] = {
	13, 49, 50, 20, 22, 90, 45, 22, 73, 132, 50, 78, 97, 55, 63, 150, 48, 153,
	145, 77, 18, 107, 11, 86, 54, 60, 156, 138, 148, 121, 160, 42, 55, 138,
	75, 72, 71, 65, 47, 80, 33, 118, 46, 104, 83, 97, 56, 136, 97, 72, 37,
	59, 41, 65, 146, 153, 104, 136, 28, 160, 31, 97, 148, 24, 83, 142, 44,
	24, 21, 49, 104, 147, 128, 37, 107, 158, 25, 64, 39, 75, 114, 104, 160,
	50, 147, 155, 160, 151, 34, 156, 90, 153, 79, 88, 91, 70, 87, 29, 115,
	145, 83, 148, 160, 49, 142, 85, 22, 27, 42, 143, 45, 18, 28, 113, 77, 64,
	113, 155, 59, 83, 124, 157, 35, 48, 97, 73, 157, 160, 73, 35, 51, 131,
	79, 47, 124, 99, 124, 136, 140, 18, 28, 20, 68, 82, 142, 157, 142, 96,
	80, 157, 128, 105, 157, 87, 134, 65, 152, 104, 59, 52, 75, 35, 59, 53,
	77, 146, 70, 29, 85, 89, 136, 59, 40, 50, 73, 18, 108, 132, 111, 95, 118,
	44, 157, 62, 128, 66, 48, 65, 61, 154, 89, 93, 86, 108, 76, 156, 26, 81,
	119, 89, 29, 107, 61, 106, 83, 69, 54, 79, 67, 157, 18, 69, 51, 51, 128,
	145, 128, 67, 128, 147, 157, 113, 97, 160, 93, 127, 133, 157, 103, 28,
	43, 114, 34, 90, 107, 155, 147, 157, 133, 27, 116, 63, 85, 50, 123, 158,
	56, 157, 22, 138, 137, 94, 160, 154, 54, 116, 53, 49, 42 };
static const uint8_t modelFuncTypes[] = {
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };

static const neurons_size_t modelOutputNeurons[] = {
	213, 232, 161, 239, 257, 248, 185, 188, 258, 246 };

#ifdef __cplusplus
}
#endif

#endif // NEUTON_MODEL_MODEL_H

